From: Antoine Coeur <co...@gmx.fr>

Correctly write 'serial', remove duplicated 'the'.

Cc: Ray Ni <ray...@intel.com>
Signed-off-by: Antoine Coeur <co...@gmx.fr>
Reviewed-by: Philippe Mathieu-Daude <phi...@redhat.com>
Acked-by: Liming Gao <liming....@intel.com>
Signed-off-by: Philippe Mathieu-Daude <phi...@redhat.com>
---
 PcAtChipsetPkg/Library/AcpiTimerLib/AcpiTimerLib.c | 2 +-
 PcAtChipsetPkg/Library/SerialIoLib/SerialPortLib.c | 6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/PcAtChipsetPkg/Library/AcpiTimerLib/AcpiTimerLib.c 
b/PcAtChipsetPkg/Library/AcpiTimerLib/AcpiTimerLib.c
index 7dc11014a588..0a49093dbf26 100644
--- a/PcAtChipsetPkg/Library/AcpiTimerLib/AcpiTimerLib.c
+++ b/PcAtChipsetPkg/Library/AcpiTimerLib/AcpiTimerLib.c
@@ -59,7 +59,7 @@ AcpiTimerLibConstructor (
 
   //
   // If the register offset to the BAR for the ACPI I/O Port Base Address is 
0x0000, then
-  // no PCI register programming is required to enable access to the the ACPI 
registers
+  // no PCI register programming is required to enable access to the ACPI 
registers
   // specified by PcdAcpiIoPortBaseAddress
   //
   if (PcdGet16 (PcdAcpiIoPciBarRegisterOffset) == 0x0000) {
diff --git a/PcAtChipsetPkg/Library/SerialIoLib/SerialPortLib.c 
b/PcAtChipsetPkg/Library/SerialIoLib/SerialPortLib.c
index 25c4cefc1381..aa5657a7fd6b 100644
--- a/PcAtChipsetPkg/Library/SerialIoLib/SerialPortLib.c
+++ b/PcAtChipsetPkg/Library/SerialIoLib/SerialPortLib.c
@@ -58,7 +58,7 @@ UINT8   gBreakSet = 0;
   If the serial device could not be initialized, then return 
RETURN_DEVICE_ERROR.
 
   @retval RETURN_SUCCESS        The serial device was initialized.
-  @retval RETURN_DEVICE_ERROR   The serail device could not be initialized.
+  @retval RETURN_DEVICE_ERROR   The serial device could not be initialized.
 
 **/
 RETURN_STATUS
@@ -139,7 +139,7 @@ SerialPortWrite (
 
   while ((NumberOfBytes--) != 0) {
     //
     // Wait for the serail port to be ready.
     //
     do {
       Data = IoRead8 ((UINT16) gUartBase + LSR_OFFSET);
@@ -180,7 +180,7 @@ SerialPortRead (
 
   while ((NumberOfBytes--) != 0) {
     //
     // Wait for the serail port to be ready.
     //
     do {
       Data = IoRead8 ((UINT16) gUartBase + LSR_OFFSET);
@@ -139,7 +139,7 @@ SerialPortWrite (
   while ((NumberOfBytes--) != 0) {
     //
-    // Wait for the serail port to be ready.
+    // Wait for the serial port to be ready.
     //
     do {
@@ -180,7 +180,7 @@ SerialPortRead (
   while ((NumberOfBytes--) != 0) {
     //
-    // Wait for the serail port to be ready.
+    // Wait for the serial port to be ready.
     //
     do {
-- 
2.21.1


-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.

View/Reply Online (#53963): https://edk2.groups.io/g/devel/message/53963
Mute This Topic: https://groups.io/mt/71040671/21656
Group Owner: devel+ow...@edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub  [arch...@mail-archive.com]
-=-=-=-=-=-=-=-=-=-=-=-

Reply via email to